"type","value"
strict              , "no"
digraph             , "yes"
graph_id            , ""
open_brace          , "1"
node_id             , "node_41"
open_bracket        , "["
attribute_id        , "color"
equals              , "="
attribute_value     , "red"
attribute_id        , "fontcolor"
equals              , "="
attribute_value     , "green"
attribute_id        , "label"
equals              , "="
attribute_value     , "ID-less graph"
close_bracket       , "]"
close_brace         , "1"
